Swiftui2Lvn.Parser (swiftui_2_lvn v0.1.6)

Parses SwiftUI code into an AST structure.

This module handles the conversion of Swift code into a tree-like AST structure that can be further processed by the Transformer.

Summary

Functions

Parses Swift code into an AST structure.

Functions

parse(code)

Parses Swift code into an AST structure.

Examples

iex> Swiftui2Lvn.Parser.parse(~s|Text("Hello")|)
%AstNode{...}