Swiftui2Lvn.ServerLauncher (swiftui_2_lvn v0.1.6)

Server launcher for VSCode plugin integration.

This module provides a simple way for the VSCode plugin to:

  1. Start the HTTP server on a random available port
  2. Get the server info (port, pid)
  3. Shut down the server gracefully

The VSCode plugin can spawn this as a separate Elixir process.

Summary

Functions

main(args \\ [])