Swiftui2Lvn.Parser (swiftui_2_lvn v0.1.6)
View SourceParses SwiftUI code into an AST structure.
This module handles the conversion of Swift code into a tree-like AST structure that can be further processed by the Transformer.
Summary
Functions
Parses Swift code into an AST structure.