Swiftui2Lvn.ServerLauncher (swiftui_2_lvn v0.1.6)
View SourceServer launcher for VSCode plugin integration.
This module provides a simple way for the VSCode plugin to:
- Start the HTTP server on a random available port
- Get the server info (port, pid)
- Shut down the server gracefully
The VSCode plugin can spawn this as a separate Elixir process.